## How to contribute to riccati

### Expectations

riccati is developed and maintained in my spare time and, while I try to be
responsive, I don't always get to every issue immediately. If it has been more
than a week or two, feel free to ping me to try to get my attention.

### Did you find a bug?

**Ensure the bug was not already reported** by searching on GitHub under
[Issues](https://github.com/fruzsinaagocs/riccati/issues). If you're unable to find an
open issue addressing the problem, [open a new
one](https://github.com/dfm/fruzsinaagocs/riccati/new). Be sure to include a **title
and clear description**, as much relevant information as possible, and the
simplest possible **code sample** demonstrating the expected behavior that is
not occurring.

### Did you write a patch that fixes a bug?

Open a new GitHub pull request with the patch. Ensure the PR description
clearly describes the problem and solution. Include the relevant issue number
if applicable.

### Do you have questions about the algorithm behind riccati in general?

**Do not open an issue,** but feel free to email me with any questions.

Thanks!

[Fruzsina](https://github.com/fruzsinaagocs)
